@@ -87,3 +87,52 @@ def simplify_value(value, decimals=4):
         value = value[:-1]
 
     return sign + value
+
+def add_sign(value):
+    """ Add sign to a number """
+
+    if value is None:
+        return None
+
+    sign = ""
+
+    if float(value) > 0:
+        sign = "+"
+    elif value == 0:
+        value = abs(value)
+
+    return f"{sign}{get_whole(value)}"
+
+def add_radix(value, symbol="’"):
+    """ Add radix to a number """
+
+    if value is None:
+        return None
+
+    value = str(value)
+
+    if '.' in value:
+        integer, fractional = value.split('.')
+    else:
+        integer = value
+        fractional = ""
+
+    if integer[0] == '-':
+        sign = "-"
+        integer = integer[1:]
+    else:
+        sign = ""
+
+    data = ""
+    ind = 0
+    for i in integer[::-1]:
+        ind += 1
+        data = i + data
+        if ind % 3 == 0:
+            data = symbol + data
+
+    data = sign + data
+    if fractional:
+        data += "." + fractional
+
+    return data
